@@ -215,7 +215,7 @@ static void reset_battery_graph( ){
 
 void battery_graph_open_dialog( ){
 	original_orientation = window.orientation;
-	if(window.orientation != O_LANDSCAPE)
+	if(window.orientation != O_LANDSCAPE && window.orientation != O_LANDSCAPE_INV)
 		rotate_screen(O_LANDSCAPE, 1);
 	dialog_open(draw_battery_graph, click_battery_graph, keypress_battery_graph, reset_battery_graph, DLG_REDRAW_ON);
 	set_timer(&dialog_refresh_timer, REFRESH_PERIOD);
