@@ -5,6 +5,7 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <glib.h>
 
 #include "main.h"
@@ -18,6 +19,9 @@ const char *conf_brightness = "/system/osso/dsm/display/display_brightness";
 const char *conf_dim_timeout = "/system/osso/dsm/display/display_dim_timeout";
 const char *conf_blank_timeout = "/system/osso/dsm/display/display_blank_timeout";
 const char *conf_volume = "/apps/osso/sound/master_volume";
+const char *conf_system_alert_volume = "/apps/osso/sound/system_alert_volume";
+const char *conf_keypad_volume = "/apps/osso/sound/keypad_volume";
+const char *conf_touchscreen_volume = "/apps/osso/sound/touchscreen_volume";
 const char *conf_screen_autolock1 = "/apps/osso/applet/osso-applet-display/lock_screen";
 const char *conf_screen_autolock2 = "/system/osso/dsm/locks/touchscreen_keypad_autolock_enabled";
 const char *conf_screen_stayslit1 = "/apps/osso/applet/osso-applet-display/display_charger";
@@ -28,6 +32,8 @@ const char *conf_theme = "/apps/asui_state/theme";
 const char *conf_ssh_server = "/apps/asui_state/ssh_server";
 const char *conf_battery_usage = "/apps/asui_state/battery_usage";
 const char *conf_screenshot_delay = "/apps/asui_state/screenshot_delay";
+const char *conf_original_screen_autolock = "/apps/asui_state/screen_autolock";
+const char *conf_original_screen_stayslit = "/apps/asui_state/screen_stayslit";
 
 const char *conf_alarm_open = "/apps/asui_state/alarm_open";
 const char *conf_alarm_tklock = "/apps/asui_state/alarm_tklock";
@@ -52,10 +58,13 @@ unsigned cfg_brightness_enhanced, cfg_brightness_allow_zero;
 // BRV keys
 unsigned cfg_buttons_rotate, cfg_buttons_brightness, cfg_buttons_brightness_step, cfg_buttons_volume, cfg_buttons_volume_step;
 // button modes
-unsigned cfg_double_tap, cfg_lock_and_close, cfg_rotate_and_close;
+unsigned cfg_double_tap, cfg_lock_and_close, cfg_rotate_and_close, cfg_split_lock_buttons;
 unsigned cfg_buttons_dpad_short, cfg_buttons_dpad_long, cfg_buttons_lock1_short, cfg_buttons_lock1_long, cfg_buttons_lock2_short, cfg_buttons_lock2_long;
-unsigned cfg_secure_action, cfg_secure_power_action, cfg_secure_button;
-unsigned cfg_power_action, cfg_power_unlock_key;
+// power button
+unsigned cfg_power_enable_double;
+unsigned cfg_power_action_single, cfg_power_action_double, cfg_power_longpress_shutdown, cfg_power_blanks_when_locked, cfg_power_unlock_key;
+// device lock
+unsigned cfg_secure_button, cfg_secure_action, cfg_secure_power_action_single, cfg_secure_power_action_double;
 // user interface
 unsigned cfg_tkactive_notifications, cfg_service_size_unit, cfg_short_tap_markers, cfg_start_visible, cfg_threshold_black, cfg_threshold_white;
 // alarm
@@ -63,6 +72,7 @@ unsigned cfg_alarm_duration, cfg_alarm_volume_min, cfg_alarm_volume_max, cfg_ala
 
 // state
 unsigned cfg_theme, cfg_ssh_server, cfg_battery_usage, cfg_screenshot_delay;
+float cfg_power_long_delay, cfg_power_double_delay;
 
 ////////////////////////////////////////////////////////////////////////// WIDGETS
 
@@ -94,6 +104,7 @@ extern s_button button_key_repeat;
 extern s_button button_screenshot;
 extern s_button button_screen_stayslit;
 extern s_button button_screen_autolock;
+extern s_button button_sounds;
 extern s_button button_settings;
 extern s_button button_edit_buttons;
 extern s_button button_edit_widgets;
@@ -133,17 +144,25 @@ static const char *conf_buttons_volume_step = "/apps/asui/buttons_volume_step";
 static const char *conf_double_tap = "/apps/asui/double_tap";
 static const char *conf_lock_and_close = "/apps/asui/lock_and_close";
 static const char *conf_rotate_and_close = "/apps/asui/rotate_and_close";
+static const char *conf_split_lock_buttons = "/apps/asui/split_lock_buttons";
 static const char *conf_buttons_dpad_short = "/apps/asui/buttons_dpad_short";
 static const char *conf_buttons_dpad_long = "/apps/asui/buttons_dpad_long";
 static const char *conf_buttons_lock1_short = "/apps/asui/buttons_lock1_short";
 static const char *conf_buttons_lock1_long = "/apps/asui/buttons_lock1_long";
 static const char *conf_buttons_lock2_short = "/apps/asui/buttons_lock2_short";
 static const char *conf_buttons_lock2_long = "/apps/asui/buttons_lock2_long";
-static const char *conf_secure_action = "/apps/asui/secure_action";
-static const char *conf_secure_power_action = "/apps/asui/secure_power_action";
-static const char *conf_secure_button = "/apps/asui/secure_button";
-static const char *conf_power_action = "/apps/asui/power_action";
+// power button
+static const char *conf_power_enable_double = "/apps/asui/power_enable_double";
+static const char *conf_power_action_single = "/apps/asui/power_action_single";
+static const char *conf_power_action_double = "/apps/asui/power_action_double";
+static const char *conf_power_longpress_shutdown = "/apps/asui/power_longpress_shutdown";
+static const char *conf_power_blanks_when_locked = "/apps/asui/power_blanks_when_locked";
 static const char *conf_power_unlock_key = "/apps/asui/power_unlock_key";
+// device lock
+static const char *conf_secure_button = "/apps/asui/secure_button";
+static const char *conf_secure_action = "/apps/asui/secure_action";
+static const char *conf_secure_power_action_single = "/apps/asui/secure_power_action_single";
+static const char *conf_secure_power_action_double = "/apps/asui/secure_power_action_double";
 // user interface
 static const char *conf_tkactive_notifications = "/apps/asui/tkactive_notifications";
 static const char *conf_service_size_unit = "/apps/asui/service_size_unit";
@@ -273,6 +292,8 @@ static void load_buttons( unsigned force_initial ){
 	load_button(&button_edit_buttons,		18, force_initial);
 	load_button(&button_edit_widgets,		19, force_initial);
 
+	load_button(&button_sounds,				16, force_initial); // new button: will land in the first empty slot if 16 isn't empty
+
 	// find empty cells for homeless buttons
 	while(button_index){
 		button_index--;
@@ -388,7 +409,7 @@ void config_init( ){
 	gconf_client_unset(gconf_client, conf_temperature_F, NULL);
 	gconf_client_unset(gconf_client, conf_history_days, NULL);
 	gconf_client_unset(gconf_client, conf_track_usage_events, NULL);
-    gconf_client_unset(gconf_client, conf_enable_battery_applet, NULL);
+gconf_client_unset(gconf_client, conf_enable_battery_applet, NULL);
 	// clock
 	gconf_client_unset(gconf_client, conf_clock_24h, NULL);
 	gconf_client_unset(gconf_client, conf_clock_ampm, NULL);
@@ -410,17 +431,25 @@ void config_init( ){
 	gconf_client_unset(gconf_client, conf_double_tap, NULL);
 	gconf_client_unset(gconf_client, conf_lock_and_close, NULL);
 	gconf_client_unset(gconf_client, conf_rotate_and_close, NULL);
+	gconf_client_unset(gconf_client, conf_split_lock_buttons, NULL);
 	gconf_client_unset(gconf_client, conf_buttons_dpad_short, NULL);
 	gconf_client_unset(gconf_client, conf_buttons_dpad_long, NULL);
 	gconf_client_unset(gconf_client, conf_buttons_lock1_short, NULL);
 	gconf_client_unset(gconf_client, conf_buttons_lock1_long, NULL);
 	gconf_client_unset(gconf_client, conf_buttons_lock2_short, NULL);
 	gconf_client_unset(gconf_client, conf_buttons_lock2_long, NULL);
-	gconf_client_unset(gconf_client, conf_secure_action, NULL);
-	gconf_client_unset(gconf_client, conf_secure_power_action, NULL);
-	gconf_client_unset(gconf_client, conf_secure_button, NULL);
-	gconf_client_unset(gconf_client, conf_power_action, NULL);
+	// power button
+	gconf_client_unset(gconf_client, conf_power_enable_double, NULL);
+	gconf_client_unset(gconf_client, conf_power_action_single, NULL);
+	gconf_client_unset(gconf_client, conf_power_action_double, NULL);
+	gconf_client_unset(gconf_client, conf_power_longpress_shutdown, NULL);
+	gconf_client_unset(gconf_client, conf_power_blanks_when_locked, NULL);
 	gconf_client_unset(gconf_client, conf_power_unlock_key, NULL);
+	// device lock
+	gconf_client_unset(gconf_client, conf_secure_button, NULL);
+	gconf_client_unset(gconf_client, conf_secure_action, NULL);
+	gconf_client_unset(gconf_client, conf_secure_power_action_single, NULL);
+	gconf_client_unset(gconf_client, conf_secure_power_action_double, NULL);
 	// user interface
 	gconf_client_unset(gconf_client, conf_tkactive_notifications, NULL);
 	gconf_client_unset(gconf_client, conf_service_size_unit, NULL);
@@ -448,7 +477,9 @@ void config_init( ){
 	gconf_client_unset(gconf_client, button_screenshot.conf, NULL);
 	gconf_client_unset(gconf_client, button_screen_stayslit.conf, NULL);
 	gconf_client_unset(gconf_client, button_screen_autolock.conf, NULL);
+	gconf_client_unset(gconf_client, button_sounds.conf, NULL);
 	gconf_client_unset(gconf_client, button_settings.conf, NULL);
+	gconf_client_unset(gconf_client, button_edit_buttons.conf, NULL);
 	gconf_client_unset(gconf_client, button_edit_widgets.conf, NULL);
 
 	gconf_client_unset(gconf_client, widget_battery.conf, NULL);
@@ -468,6 +499,18 @@ void config_init( ){
 	gconf_client_unset(gconf_client, conf_ssh_server, NULL);
 	gconf_client_unset(gconf_client, conf_battery_usage, NULL);
 	gconf_client_unset(gconf_client, conf_screenshot_delay, NULL);
+	gconf_client_unset(gconf_client, conf_original_screen_autolock, NULL);
+	gconf_client_unset(gconf_client, conf_original_screen_stayslit, NULL);
+	gconf_client_unset(gconf_client, conf_alarm_open, NULL);
+	gconf_client_unset(gconf_client, conf_alarm_tklock, NULL);
+	gconf_client_unset(gconf_client, conf_alarm_cb_service, NULL);
+	gconf_client_unset(gconf_client, conf_alarm_cb_path, NULL);
+	gconf_client_unset(gconf_client, conf_alarm_cb_iface, NULL);
+	gconf_client_unset(gconf_client, conf_alarm_cb_method, NULL);
+	gconf_client_unset(gconf_client, conf_alarm_description, NULL);
+	gconf_client_unset(gconf_client, conf_alarm_sound, NULL);
+	gconf_client_unset(gconf_client, conf_alarm_mode, NULL);
+	gconf_client_unset(gconf_client, conf_alarm_timestamp, NULL);
 	gconf_client_unset(gconf_client, "/apps/asui_state", NULL);
 
 	printf("all gconf keys cleared\n");
@@ -479,6 +522,8 @@ void config_init( ){
 	gconf_client_unset(gconf_client, "/apps/asui/brightness_level", NULL); // removed in 0.4.5
 	gconf_client_unset(gconf_client, "/apps/asui/n800_lock_mode", NULL); // removed in 0.5.7
 	gconf_client_unset(gconf_client, "/apps/asui/softpoweroff_mode", NULL); // added and removed in 0.5.7 test releases
+	gconf_client_unset(gconf_client, "/apps/asui/power_action", NULL); // removed in 0.5.8
+	gconf_client_unset(gconf_client, "/apps/asui/secure_power_action", NULL); // removed in 0.5.8
 
 	first_config_load = 1;
 	config_reload();
@@ -568,17 +613,25 @@ void config_reload( ){
 	make_bool(&cfg_double_tap,				conf_double_tap,				1,		0);					// default: 1	require double taps where available
 	make_bool(&cfg_lock_and_close,			conf_lock_and_close,			1,		0);					// default: 1	close window after using on-screen lock buttons
 	make_bool(&cfg_rotate_and_close,		conf_rotate_and_close,			1,		0);					// default: 1	close window after using on-screen rotation buttons
+	make_bool(&cfg_split_lock_buttons,		conf_split_lock_buttons,		0,		HW_THEME);			// default: 0	disabled, use long press
 	make_uint(&cfg_buttons_dpad_short,		conf_buttons_dpad_short,		1,		0);					// default: 0	lock
 	make_uint(&cfg_buttons_dpad_long,		conf_buttons_dpad_long,			4,		0);					// default: 0	secure
 	make_uint(&cfg_buttons_lock1_short,		conf_buttons_lock1_short,		2,		HW_THEME);			// default: 0	lock&blank
 	make_uint(&cfg_buttons_lock1_long,		conf_buttons_lock1_long,		3,		HW_THEME);			// default: 0	blank
 	make_uint(&cfg_buttons_lock2_short,		conf_buttons_lock2_short,		1,		HW_THEME);			// default: 0	lock
 	make_uint(&cfg_buttons_lock2_long,		conf_buttons_lock2_long,		4,		HW_THEME);			// default: 0	secure
-	make_uint(&cfg_secure_action,			conf_secure_action,				2,		0);					// default: 0	lock&blank
-	make_uint(&cfg_secure_power_action,		conf_secure_power_action,		1,		0);					// default: 0	lock&blank
+	// power button
+	make_bool(&cfg_power_enable_double,		conf_power_enable_double,		1,		0);					// default: 1	enabled
+	make_uint(&cfg_power_action_single,		conf_power_action_single,		(is_810 ? POWER_ACTION_OPENCLOSE:POWER_ACTION_OPEN), 0);
+	make_uint(&cfg_power_action_double,		conf_power_action_double,		0,		0);					// default: 0	none
+	make_bool(&cfg_power_longpress_shutdown,conf_power_longpress_shutdown,	0,		0);					// default: 0   disabled
+	make_bool(&cfg_power_blanks_when_locked,conf_power_blanks_when_locked,	0,		0);					// default: 0   disabled
+	make_uint(&cfg_power_unlock_key,		conf_power_unlock_key,			(is_810 ? 1:4), 0);			// default: 1/4 power button + fullscreen/dpad key unlocks
+	// device lock
 	make_bool(&cfg_secure_button,			conf_secure_button,				0,		HW_THEME);			// default: 0	don't show secure button
-	make_uint(&cfg_power_action, 			conf_power_action,			(is_810 ? 2:1),	0);				// default: -	open/close for n810, open-only for n800/770
-	make_uint(&cfg_power_unlock_key,		conf_power_unlock_key,		(is_810 ? 1:4),	0);				// default: 1/4	power button + fullscreen/dpad key unlocks
+	make_uint(&cfg_secure_action,			conf_secure_action,				2,		0);					// default: 0	lock&blank
+	make_uint(&cfg_secure_power_action_single,conf_secure_power_action_single,POWER_ACTION_LOCKBLANK, 0);
+	make_uint(&cfg_secure_power_action_double,conf_secure_power_action_double,0,	0);					// default: 0	none
 	// user interface
 	make_bool(&cfg_tkactive_notifications,	conf_tkactive_notifications,	1,		0);					// default: 1	show screen on unlock notifications
 	make_bool(&cfg_service_size_unit,		conf_service_size_unit,			1,		HW_THEME);			// default: 1	show MB with service sizes
@@ -663,11 +716,17 @@ void config_reload( ){
 	if(cfg_buttons_lock1_long > 4){ cfg_buttons_lock1_long = 0; conf_set_int(conf_buttons_lock1_long, 0); } // disable if invalid
 	if(cfg_buttons_lock2_short > 4){ cfg_buttons_lock2_short = 0; conf_set_int(conf_buttons_lock2_short, 0); } // disable if invalid
 	if(cfg_buttons_lock2_long > 4){ cfg_buttons_lock2_long = 0; conf_set_int(conf_buttons_lock2_long, 0); } // disable if invalid
-	if(cfg_secure_action > 3){ cfg_secure_action = 2; conf_set_int(conf_secure_action, 2); } // revert to default if invalid
-	if(cfg_secure_power_action > 2){ cfg_secure_power_action = 1; conf_set_int(conf_secure_power_action, 1); } // revert to default if invalid
-	if(cfg_power_action > 2){ cfg_power_action = (is_810 ? 2:1); conf_set_int(conf_power_action, cfg_power_action); } // revert to default if invalid
+
+	// bounds check power actions
+	if(cfg_power_action_single > POWER_ACTION_OPENCLOSE){ cfg_power_action_single = (is_810 ? POWER_ACTION_OPENCLOSE:POWER_ACTION_OPEN); conf_set_int(conf_power_action_single, cfg_power_action_single); } // revert to default if invalid
+	if(cfg_power_action_double > POWER_ACTION_OPENCLOSE){ cfg_power_action_double = (is_810 ? POWER_ACTION_OPENCLOSE:POWER_ACTION_OPEN); conf_set_int(conf_power_action_double, cfg_power_action_double); } // revert to default if invalid
 	if(cfg_power_unlock_key > 5){ cfg_power_unlock_key = (is_810 ? 1:4); conf_set_int(conf_power_unlock_key, cfg_power_unlock_key); } // revert to default if invalid
 
+	// bounds check secure actions
+	if(cfg_secure_action > POWER_ACTION_BLANK){ cfg_secure_action = POWER_ACTION_LOCKBLANK; conf_set_int(conf_secure_action, cfg_secure_action); } // revert to default if invalid
+	if(cfg_secure_power_action_single > POWER_ACTION_BLANK){ cfg_secure_power_action_single = POWER_ACTION_LOCKBLANK; conf_set_int(conf_secure_power_action_single, cfg_secure_power_action_single); } // revert to default if invalid
+	if(cfg_secure_power_action_double > POWER_ACTION_BLANK){ cfg_secure_power_action_double = 0; conf_set_int(conf_secure_power_action_double, cfg_secure_power_action_double); } // revert to default if invalid
+
 // override until 770 is supported
 if(cfg_brightness_enhanced && is_770){ cfg_brightness_enhanced = 0; conf_set_bool(conf_brightness_enhanced, 0); } // disable
 
@@ -709,6 +768,60 @@ if(cfg_brightness_enhanced && is_770){ cfg_brightness_enhanced = 0; conf_set_boo
 	prev_brightness_enhanced = cfg_brightness_enhanced;
 	prev_battery_idle_time = cfg_battery_idle_time;
 
+	// read mce.ini
+	{
+		unsigned long_delay = 1500, long_shutdown = 0;
+		unsigned double_delay = 1000, double_action = 0;
+		FILE *in;
+		if((in = fopen("/etc/mce/mce.ini", "r")) != NULL){
+			debug_write("MCE.INI");
+			while(!feof(in)){
+				char line[400];
+				fgets(line, 400, in);
+				if(feof(in)) break;
+
+				if(!strncmp(line, "PowerKeyLongDelay=", 18)){
+					// get long delay, unless commented out
+					sscanf(&line[18], "%u", &long_delay);
+					debug_write("  power button long delay = %u", long_delay);
+				} else if(!strncmp(line, "PowerKeyDoubleDelay=", 20)){
+					// get double delay, unless commented out
+					sscanf(&line[20], "%u", &double_delay);
+					debug_write("  power button double delay = %u", double_delay);
+				} else if(!strncmp(line, "PowerKeyLongAction=", 19)){
+					// get long action, assume 'disabled' if commented out
+					if(!strncmp(&line[19], "poweroff", 8)){
+						long_shutdown = 1;
+						debug_write("  power button long action = SHUTDOWN");
+					} else {
+						#ifdef DEBUG
+						line[strlen(line)-1] = '\0';
+						#endif
+						debug_write("  power button long action = '%s'", &line[19]);
+					}
+				} else if(!strncmp(line, "PowerKeyDoubleAction=", 21)){
+					// get double action, assume 'disabled' if commented out
+					if(strncmp(&line[21], "disabled", 8)){
+						double_action = 1;
+						#ifdef DEBUG
+						line[strlen(line)-1] = '\0';
+						#endif
+						debug_write("  power button double action = '%s'", &line[21]);
+					} else {
+						double_action = 0;
+						debug_write("  power button double action = DISABLED");
+					}
+				}
+			}
+			fclose(in);
+		}
+
+		cfg_power_long_delay = (float)long_delay / 1000.0;
+		cfg_power_double_delay = (float)double_delay / 1000.0;
+		if(!long_shutdown && cfg_power_longpress_shutdown){ cfg_power_longpress_shutdown = 0; conf_set_bool(conf_power_longpress_shutdown, 0); } // disable LP shutdown
+		if(double_action && !cfg_power_enable_double){ cfg_power_enable_double = 1; conf_set_bool(conf_power_enable_double, 1); } // enabled double-tap support
+	}
+
 	#else
 
 	cfg_history_days = 0;
@@ -726,9 +839,9 @@ if(cfg_brightness_enhanced && is_770){ cfg_brightness_enhanced = 0; conf_set_boo
 	cfg_buttons_lock1_long = 3;
 	cfg_buttons_lock2_short = 2;
 	cfg_buttons_lock2_long = 4;
-	cfg_secure_action = 2;
-	cfg_secure_power_action = 1;
-	cfg_secure_button = 1; // disable secure buttons
+
+	cfg_secure_button = 1; // enable secure button
+	cfg_secure_action = POWER_ACTION_NONE;
 
 	cfg_short_tap_markers = 1; // show all markers
 	cfg_start_visible = 1; // no power button to map it
@@ -773,17 +886,25 @@ if(cfg_brightness_enhanced && is_770){ cfg_brightness_enhanced = 0; conf_set_boo
 	debug_write("  cfg_double_tap = %u", cfg_double_tap);
 	debug_write("  cfg_lock_and_close = %u", cfg_lock_and_close);
 	debug_write("  cfg_rotate_and_close = %u", cfg_rotate_and_close);
+	debug_write("  cfg_split_lock_buttons = %u", cfg_split_lock_buttons);
 	debug_write("  cfg_buttons_dpad_short = %u", cfg_buttons_dpad_short);
 	debug_write("  cfg_buttons_dpad_long = %u", cfg_buttons_dpad_long);
 	debug_write("  cfg_buttons_lock1_short = %u", cfg_buttons_lock1_short);
 	debug_write("  cfg_buttons_lock1_long = %u", cfg_buttons_lock1_long);
 	debug_write("  cfg_buttons_lock2_short = %u", cfg_buttons_lock2_short);
 	debug_write("  cfg_buttons_lock2_long = %u", cfg_buttons_lock2_long);
-	debug_write("  cfg_secure_action = %u", cfg_secure_action);
-	debug_write("  cfg_secure_power_action = %u", cfg_secure_power_action);
-	debug_write("  cfg_secure_button = %u", cfg_secure_button);
-	debug_write("  cfg_power_action = %u", cfg_power_action);
+	// power button
+	debug_write("  cfg_power_enable_double = %u", cfg_power_enable_double);
+	debug_write("  cfg_power_action_single = %u", cfg_power_action_single);
+	debug_write("  cfg_power_action_double = %u", cfg_power_action_double);
+	debug_write("  cfg_power_longpress_shutdown = %u", cfg_power_longpress_shutdown);
+	debug_write("  cfg_power_blanks_when_locked = %u", cfg_power_blanks_when_locked);
 	debug_write("  cfg_power_unlock_key = %u", cfg_power_unlock_key);
+	// device lock
+	debug_write("  cfg_secure_button = %u", cfg_secure_button);
+	debug_write("  cfg_secure_action = %u", cfg_secure_action);
+	debug_write("  cfg_secure_power_action_single = %u", cfg_secure_power_action_single);
+	debug_write("  cfg_secure_power_action_double = %u", cfg_secure_power_action_double);
 	// user interface
 	debug_write("  cfg_tkactive_notifications = %u", cfg_tkactive_notifications);
 	debug_write("  cfg_service_size_unit = %u", cfg_service_size_unit);
@@ -804,6 +925,8 @@ if(cfg_brightness_enhanced && is_770){ cfg_brightness_enhanced = 0; conf_set_boo
 	debug_write("  cfg_ssh_server = %u", cfg_ssh_server);
 	debug_write("  cfg_battery_usage = %u", cfg_battery_usage);
 	debug_write("  cfg_screenshot_delay = %u", cfg_screenshot_delay);
+	debug_write("  cfg_power_long_delay = %.3f", cfg_power_long_delay);
+	debug_write("  cfg_power_double_delay = %.3f", cfg_power_double_delay);
 	debug_write("------------------------------");
 }
 
