@@ -5,6 +5,9 @@ extern const char *conf_brightness;
 extern const char *conf_dim_timeout;
 extern const char *conf_blank_timeout;
 extern const char *conf_volume;
+extern const char *conf_system_alert_volume;
+extern const char *conf_keypad_volume;
+extern const char *conf_touchscreen_volume;
 extern const char *conf_screen_autolock1;
 extern const char *conf_screen_autolock2;
 extern const char *conf_screen_stayslit1;
@@ -15,6 +18,8 @@ extern const char *conf_theme;
 extern const char *conf_ssh_server;
 extern const char *conf_battery_usage;
 extern const char *conf_screenshot_delay;
+extern const char *conf_original_screen_autolock;
+extern const char *conf_original_screen_stayslit;
 
 extern const char *conf_alarm_open;
 extern const char *conf_alarm_tklock;
@@ -39,10 +44,13 @@ extern unsigned cfg_brightness_enhanced, cfg_brightness_allow_zero;
 // BRV keys
 extern unsigned cfg_buttons_rotate, cfg_buttons_brightness, cfg_buttons_brightness_step, cfg_buttons_volume, cfg_buttons_volume_step;
 // button modes
-extern unsigned cfg_double_tap, cfg_lock_and_close, cfg_rotate_and_close;
+extern unsigned cfg_double_tap, cfg_lock_and_close, cfg_rotate_and_close, cfg_split_lock_buttons;
 extern unsigned cfg_buttons_dpad_short, cfg_buttons_dpad_long, cfg_buttons_lock1_short, cfg_buttons_lock1_long, cfg_buttons_lock2_short, cfg_buttons_lock2_long;
-extern unsigned cfg_secure_action, cfg_secure_power_action, cfg_secure_button;
-extern unsigned cfg_power_action, cfg_power_unlock_key;
+// power button
+extern unsigned cfg_power_enable_double;
+extern unsigned cfg_power_action_single, cfg_power_action_double, cfg_power_longpress_shutdown, cfg_power_blanks_when_locked, cfg_power_unlock_key;
+// device lock
+extern unsigned cfg_secure_button, cfg_secure_action, cfg_secure_power_action_single, cfg_secure_power_action_double;
 // user interface
 extern unsigned cfg_tkactive_notifications, cfg_service_size_unit, cfg_short_tap_markers, cfg_start_visible, cfg_threshold_black, cfg_threshold_white;
 // alarm
@@ -50,12 +58,13 @@ extern unsigned cfg_alarm_duration, cfg_alarm_volume_min, cfg_alarm_volume_max,
 
 // state
 extern unsigned cfg_theme, cfg_ssh_server, cfg_battery_usage, cfg_screenshot_delay;
+extern float cfg_power_long_delay, cfg_power_double_delay;
 
 #define CFG_BUTTONS_ZOOM 1
 #define CFG_BUTTONS_UD 2
 #define CFG_BUTTONS_LR 3
 
-enum { POWER_ACTION_LOCKBLANK = 0, POWER_ACTION_OPEN, POWER_ACTION_OPENCLOSE };
+enum { POWER_ACTION_NONE, POWER_ACTION_LOCK, POWER_ACTION_LOCKBLANK, POWER_ACTION_BLANK, POWER_ACTION_OPEN, POWER_ACTION_OPENCLOSE };
 
 #define MIN_SCREENSHOT_DELAY 1
 #define MAX_SCREENSHOT_DELAY 20
