@@ -36,8 +36,6 @@ unsigned dbus_listening;
 
 int dbus_wakeup_fd;
 
-unsigned original_screen_autolock, original_screen_stayslit;
-
 ////////////////////////////////////////////////////////////////////////// LOCAL GLOBALS
 
 static pthread_t thread;
@@ -55,7 +53,6 @@ static const char *_osso_multimedia_path_ = "/com/nokia/osso_media_server";
 static const char *_osso_multimedia_interface_ = "com.nokia.osso_media_server.sound";
 
 static unsigned acting_dead_state;
-//static unsigned powerkeymenu_open;
 #endif
 
 //////////////////////////////////////////////////////////////////////////
@@ -181,13 +178,39 @@ static DBusHandlerResult signal_filter( DBusConnection *connection, DBusMessage
 
 	////////////////////
 	// SYSTEM UI
-//	} else if(dbus_message_is_method_call(message, "com.nokia.system_ui.request", "tklock_open")){
+/*	} else if(dbus_message_is_method_call(message, "com.nokia.system_ui.request", "tklock_open")){
+		char *cb_service, *cb_path, *cb_iface, *cb_method;
+		unsigned mode, unknown1, unknown2;
 
-		// signature = ssssubb
+		if(dbus_message_get_args(message, &dbus_error, _STRING_, &cb_service, _STRING_, &cb_path, _STRING_, &cb_iface, _STRING_, &cb_method,
+		   _UINT32_, &mode, _BOOL_, &unknown1, _BOOL_, &unknown2, _END_))
+		{
+			debug_write("[DBUS] method: com.nokia.system_ui.request.tklock_open(%u, %s,%s)", mode, (unknown1 ? "TRUE" : "FALSE"), (unknown2 ? "TRUE" : "FALSE"));
 
-//	} else if(dbus_message_is_method_call(message, "com.nokia.system_ui.request", "tklock_close")){
+			// method doesn't expect a reply
 
-		// signature = b
+int status = 1; // TkLockReplyOk
+dbus_send_method(cb_service, cb_path, cb_iface, cb_method, _INT32_, &status, _END_);
+
+			// - lock from powerkey menu										(1, false, true)
+			// - press power button to turn screen on and require unlock key	(3, false, true)
+			// - screen times out but doesn't lock								(4,  true, true)
+
+			return DBUS_HANDLER_RESULT_HANDLED;
+		}
+
+	} else if(dbus_message_is_method_call(message, "com.nokia.system_ui.request", "tklock_close")){
+		unsigned mode;
+
+		if(dbus_message_get_args(message, &dbus_error, _BOOL_, &mode, _END_)){
+			debug_write("[DBUS] method: com.nokia.system_ui.request.tklock_close(%s)", (mode ? "TRUE" : "FALSE"));
+
+			// - when screen is turned back on but wasn't locked	(true)
+			// - when screen was locked								(false)
+
+			return DBUS_HANDLER_RESULT_HANDLED;
+		}
+*/
 
 	} else if(dbus_message_is_method_call(message, "com.nokia.system_ui.request", "devlock_open")){
 
@@ -331,7 +354,7 @@ acting_dead_state = 0;
 			//		alarm
 			//		screen locked
 
-			// it would complicate the code to have it split between the buttonpressed:power and powerkeymenu_open signals
+			// this is handled by powerbutton.c
 
 			return DBUS_HANDLER_RESULT_HANDLED;
 		}
@@ -358,6 +381,24 @@ acting_dead_state = 0;
 		// ignore unmatched signatures
 */
 
+
+//	} else if(dbus_message_is_method_call(message, "com.nokia.system_ui.request", "splashscreen_open")){
+
+		// signature = ub
+		// (2,true) when shutting down
+
+//	} else if(dbus_message_is_method_call(message, "com.nokia.system_ui.request", "splashscreen_close")){
+
+		// signature = <unknown>
+
+//	} else if(dbus_message_is_method_call(message, "com.nokia.system_ui.request", "modechange_open")){
+
+		// signature = <unknown>
+
+//	} else if(dbus_message_is_method_call(message, "com.nokia.system_ui.request", "modechange_close")){
+
+		// signature = <none>
+
 	////////////////////
 	// HAL
 	} else if(dbus_message_is_signal(message, "org.freedesktop.Hal.Device", "Condition")){
@@ -367,80 +408,15 @@ acting_dead_state = 0;
 
 		if(dbus_message_get_args(message, &dbus_error, _STRING_, &s1, _STRING_, &s2, _END_)){
 			if(!strcmp(s1, "ButtonPressed")){
-				if(!strcmp(s2, "power")){
+//				if(!strcmp(s2, "power")){
 					// path = /org/freedesktop/Hal/devices/computer_logicaldev_input
 					// path = /org/freedesktop/Hal/devices/computer_logicaldev_input_0
-					debug_write("[DBUS]         power button pressed (blank=%u)", blank_window_open);
 
-					// this signal will turn on the screen, if off
-					dsme_display_state_waiting = 0; // reset blanking pause check
+					// this is handled by powerbutton.c
 
-					if(use_minimal_ui || current_dialog_draw == draw_alarm){
-						// charging runlevel or alarm active, power button does nothing
-
-					} else if(hw_screen.visible && current_time - hw_screen.visible_time > 1.0){
-						// screen has been on for more than one second
-						// CASE: power button used to blank screen (when locked)
-						// CASE: power button used to lock, lock&blank or blank screen (when devlocked)
-						// CASE: power button used to map/unmap ASUI
-
-						// main loop doesn't need to be awakened, unless showing or hiding ASUI
-
-debug_write("PB: screen has been on for more than one second, tklock=%u, asui=%u", hw_screen.locked, window.is_mapped);
-						if(hw_screen.locked){
-							hw_lock_keys(); // MCE unlocked the keys for SystemUI's secondary unlock key, relock them
-
-							// screen is locked, power button will blank it
-							int i;
-							for(i = 0; i < 20; i++){
-								if(hw_screen.dimmed) break;
-								usleep(100000); // sleep 20 x 100ms until screen dims
-							}
-							mce_lock_and_blank_screen();
-						} else if(cfg_power_action == POWER_ACTION_LOCKBLANK){
-							// lock&blank screen instead of mapping or unmapping ASUI
-							mce_lock_and_blank_screen();
-						} else if(window.is_mapped){
-							if(hw_device_locked){
-								// device is locked, power button will invoke the secure_power_action
-								press_lock_button(cfg_secure_power_action+1);
-							} else if(cfg_power_action == POWER_ACTION_OPENCLOSE){
-								// unmap ASUI unless n800_lock_mode is enabled
-								dbus_send_wakeup(_WAKEUP_HIDE_);
-							}
-						} else {
-							// map ASUI
-							dbus_send_wakeup(_WAKEUP_SHOW_);
-						}
-					} else {
-						// screen is in the process of turning on or has been on less than one second
-						// CASE: power button used to turn on screen (locked or unlocked)
-
-						// main loop doesn't need to be awakened, DSME socket will do it
-
-debug_write("PB: screen is in the process of turning on, tklock=%u", hw_screen.locked);
-						if(hw_screen.locked){
-							if(cfg_power_unlock_key){
-debug_write("-- secondary key required to unlock, tc=1, kc=0, asui=%u", window.is_mapped);
-								// secondary key required to unlock screen, keypad remains unlocked
-								hw_lock_screen();
-								hw_unlock_keys();
-								if(!window.is_mapped) window_open_blank(); // open blank to catch keys
-								notify_power_unlock_key();
-							} else {
-								// screen needs to be unlocked
-								window_close_blank(); // power key caught, close the blank window
-								mce_unlock_screen();
-							}
-						} else {
-							// screen wasn't locked
-							window_close_blank(); // power key caught, close the blank window
-							if(cfg_tkactive_notifications) notify_screen_unlocked();
-						}
-					}
-
-					return DBUS_HANDLER_RESULT_HANDLED;
-				} else if(!strcmp(s2, "connection")){
+//					return DBUS_HANDLER_RESULT_HANDLED;
+//				} else 
+				if(!strcmp(s2, "connection")){
 					// path = /org/freedesktop/Hal/devices/platform_headphone
 					debug_write("[DBUS]         headphone connect/disconnect (blank=%u)", blank_window_open);
 
@@ -664,6 +640,17 @@ debug_write("-- secondary key required to unlock, tc=1, kc=0, asui=%u", window.i
 
 		hw_restore_cp_screen_settings();
 
+// TODO: sound is eventually played when entering charging runlevel but system goes down before it can be played when not on charger
+/*
+		unsigned system_alert_volume = conf_get_int(conf_system_alert_volume);
+		if(system_alert_volume){
+			// play shutdown sound file
+			dbus_audio_set_volume(system_alert_volume * 0.5);
+			dbus_audio_set_loop(0);
+			dbus_audio_play(conf_get_string("/system/systemui/splash/shutdown_soundfilename"), 1);
+		}
+*/
+
 		dbus_send_wakeup(_WAKEUP_SHUTDOWN_);
 
 		return DBUS_HANDLER_RESULT_HANDLED;
@@ -806,8 +793,6 @@ debug_write("-- secondary key required to unlock, tc=1, kc=0, asui=%u", window.i
 				hw_bluetooth.enabled = enabled;
 				hw_bluetooth.visible = visible;
 				if(is_value_visible(bluetooth_widget_page)){ hw_changes |= HW_BLUETOOTH; dbus_send_wakeup(_WAKEUP_REFRESH_); }
-
-				if(!hw_bluetooth.enabled && hw_entering_flight_mode) mce_flight_mode();
 			}
 		}
 
@@ -1020,6 +1005,10 @@ debug_write("-- secondary key required to unlock, tc=1, kc=0, asui=%u", window.i
 		if(dbus_message_get_args(message, &dbus_error, _STRING_, &s, _END_)){
 			debug_write("[DBUS ERROR] %s", s);
 			test_write("[DBUS ERROR] %s", s);
+			debug_write("             dest=%s %s %s.%s (%s)", dbus_message_get_destination(message), dbus_message_get_path(message), dbus_message_get_interface(message),
+																dbus_message_get_member(message), dbus_message_get_signature(message));
+			test_write("             dest=%s %s %s.%s (%s)", dbus_message_get_destination(message), dbus_message_get_path(message), dbus_message_get_interface(message),
+																dbus_message_get_member(message), dbus_message_get_signature(message));
 		}
 
 		return DBUS_HANDLER_RESULT_HANDLED;
@@ -1036,9 +1025,8 @@ debug_write("-- secondary key required to unlock, tc=1, kc=0, asui=%u", window.i
 	test_write("       dest=%s %s %s.%s (%s)", dbus_message_get_destination(message), dbus_message_get_path(message), dbus_message_get_interface(message),
 												dbus_message_get_member(message), dbus_message_get_signature(message));
 	test_write("       wants reply? = %s", (dbus_message_get_no_reply(message) ? "no" : "yes"));
-	return DBUS_HANDLER_RESULT_HANDLED;
 	#else
-		#ifdef DEBUGLOG
+		#ifdef DEBUG
 		switch(dbus_message_get_type(message)){
 		case DBUS_MESSAGE_TYPE_METHOD_CALL: debug_write("[DBUS] received unhandled METHOD CALL"); break;
 		case DBUS_MESSAGE_TYPE_METHOD_RETURN: debug_write("[DBUS] received unhandled METHOD RETURN"); break;
@@ -1048,11 +1036,9 @@ debug_write("-- secondary key required to unlock, tc=1, kc=0, asui=%u", window.i
 		debug_write("       dest=%s %s %s.%s (%s)", dbus_message_get_destination(message), dbus_message_get_path(message), dbus_message_get_interface(message),
 													dbus_message_get_member(message), dbus_message_get_signature(message));
 		debug_write("       wants reply? = %s", (dbus_message_get_no_reply(message) ? "no" : "yes"));
-		return DBUS_HANDLER_RESULT_HANDLED;
-		#else
-		return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
 		#endif
 	#endif
+	return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
 }
 #endif
 
@@ -1084,13 +1070,17 @@ static void *dbus_thread( void *arg ){
 		dbus_bus_add_match(signal_bus, "type='method_call',path='/com/nokia/system_ui/request',interface='com.nokia.system_ui.request',member='acring_dead_getstate'", &dbus_error);
 //		dbus_bus_add_match(signal_bus, "type='method_call',path='/com/nokia/system_ui/request',interface='com.nokia.system_ui.request',member='powerkeymenu_open'", &dbus_error);
 //		dbus_bus_add_match(signal_bus, "type='method_call',path='/com/nokia/system_ui/request',interface='com.nokia.system_ui.request',member='powerkeymenu_close'", &dbus_error);
+//		dbus_bus_add_match(signal_bus, "type='method_call',path='/com/nokia/system_ui/request',interface='com.nokia.system_ui.request',member='splashscreen_open'", &dbus_error);
+//		dbus_bus_add_match(signal_bus, "type='method_call',path='/com/nokia/system_ui/request',interface='com.nokia.system_ui.request',member='splashscreen_close'", &dbus_error);
+//		dbus_bus_add_match(signal_bus, "type='method_call',path='/com/nokia/system_ui/request',interface='com.nokia.system_ui.request',member='modechange_open'", &dbus_error);
+//		dbus_bus_add_match(signal_bus, "type='method_call',path='/com/nokia/system_ui/request',interface='com.nokia.system_ui.request',member='modechange_close'", &dbus_error);
 */
 
 		// power button signal
-		dbus_bus_add_match(signal_bus, "type='signal',path='/org/freedesktop/Hal/devices/computer_logicaldev_input',"   // n800
-										"interface='org.freedesktop.Hal.Device',member='Condition',arg0='ButtonPressed',arg1='power'", &dbus_error);
-		dbus_bus_add_match(signal_bus, "type='signal',path='/org/freedesktop/Hal/devices/computer_logicaldev_input_0'," // n810
-										"interface='org.freedesktop.Hal.Device',member='Condition',arg0='ButtonPressed',arg1='power'", &dbus_error);
+//		dbus_bus_add_match(signal_bus, "type='signal',path='/org/freedesktop/Hal/devices/computer_logicaldev_input',"   // n800
+//										"interface='org.freedesktop.Hal.Device',member='Condition',arg0='ButtonPressed',arg1='power'", &dbus_error);
+//		dbus_bus_add_match(signal_bus, "type='signal',path='/org/freedesktop/Hal/devices/computer_logicaldev_input_0'," // n810
+//										"interface='org.freedesktop.Hal.Device',member='Condition',arg0='ButtonPressed',arg1='power'", &dbus_error);
 		// headphone jack
 		dbus_bus_add_match(signal_bus, "type='signal',path='/org/freedesktop/Hal/devices/platform_headphone',"
 										"interface='org.freedesktop.Hal.Device',member='Condition',arg0='ButtonPressed',arg1='connection'", &dbus_error);
@@ -1104,7 +1094,7 @@ static void *dbus_thread( void *arg ){
 		// n810 lock key
 //		dbus_bus_add_match(signal_bus, "type='signal',path='/org/freedesktop/Hal/devices/platform_kb_lock_0',"
 //										"interface='org.freedesktop.Hal.Device',member='Condition',arg0='ButtonPressed',arg1='cover'", &dbus_error);
-		// n810 mmc card
+		// mmc card
 		dbus_bus_add_match(signal_bus, "type='signal',path='/org/freedesktop/Hal/devices/platform_mmci_omap_1_mmc_host',"
 										"interface='org.freedesktop.Hal.Device',member='Condition',arg0='ButtonPressed',arg1='cover'", &dbus_error);
 		// usb jack
@@ -1169,9 +1159,7 @@ static void *dbus_thread( void *arg ){
 
 int dbus_init( ){
 	#ifdef ARCH_armel
-	original_screen_autolock = original_screen_stayslit = 0;
 	acting_dead_state = 0;
-//	powerkeymenu_open = 0;
 
 	dbus_threads_init_default();
 	dbus_error_init(&dbus_error);
@@ -1386,6 +1374,7 @@ void dbus_audio_set_loop( unsigned loop ){
 
 void dbus_audio_play( char *sound, int priority ){
 	#ifdef ARCH_armel
+	if(sound == NULL) return;
 	dbus_send_session_method(_osso_multimedia_service_, _osso_multimedia_path_, _osso_multimedia_interface_, "play_sound", _STRING_, &sound, _INT32_, &priority, _END_);
 	#endif
 }
