@@ -54,7 +54,7 @@ void dialog_close( ){
 
 void dialog_reset( ){
 	// set all widgets to the inactive page to avoid redraw problems
-	brightness_widget_page = volume_widget_page = battery_widget_page = flightmode_button_page = keyrepeat_button_page = screenstayslit_button_page = screenautolock_button_page = !primary_widgets;
+	brightness_widget_page = volume_widget_page = battery_widget_page = wifi_widget_page = bluetooth_widget_page = usb_widget_page = flightmode_button_page = keyrepeat_button_page = screenstayslit_button_page = screenautolock_button_page = !primary_widgets;
 
 	if(current_dialog_reset) current_dialog_reset();
 	current_dialog_draw = current_dialog_click = current_dialog_keypress = current_dialog_reset = NULL;
