@@ -266,7 +266,11 @@ static e_dsme_display_state expected_display_state;
 static s_timer display_state_timer;
 
 void dsme_expect_display_state( e_dsme_display_state state ){
-	expected_display_state = state;
+	// if screen is expected to dim but blank timeout equals dim timeout then it will always transition from on to off without dimming
+	if(conf_get_int(conf_blank_timeout) == conf_get_int(conf_dim_timeout) && state == DSME_DISPLAY_DIM)
+		expected_display_state = DSME_DISPLAY_OFF;
+	else
+		expected_display_state = state;
 	dsme_display_state_waiting = 2;
 	set_timer(&display_state_timer, 6.0); // 6 seconds
 	dbus_send_wakeup(_WAKEUP_REFRESH_);
@@ -281,10 +285,12 @@ double dsme_check_display_state( ){
 		} else if(dsme_display_state_waiting == 2){
 			// MCE did not set the expected state yet, blanking is most likely paused
 			// send first notification and set a second timer
+			debug_write("blanking pause detected...");
 			notify_blanking_pause1();
 			dsme_display_state_waiting--;
 			set_timer(&display_state_timer, 3.0); // 3 seconds
-		} else {
+			hw_restore_cp_screen_settings();
+		} else if(dsme_display_state_waiting){
 			// send second notification and end timer
 			notify_blanking_pause2();
 			dsme_display_state_waiting--;
