@@ -196,7 +196,7 @@ static void keypress_governor_dsp( ){
 
 //////////////////////////////////////////////////////////////////////////
 
-void governor_open_dialog( ){
+void governor_dsp_open_dialog( ){
 	dialog_open(draw_governor_dsp, click_governor_dsp, keypress_governor_dsp, NULL, DLG_REDRAW_ON);
 	set_timer(&dialog_refresh_timer, REFRESH_PERIOD);
 }
