@@ -12,6 +12,9 @@
 //
 //	Bluetooth d-bus calls from 'switch on BT' package
 
+// the percentage capacity must increase to reset the charging point
+#define MIN_CHARGE_RESET 1.0
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -386,16 +389,29 @@ void mce_init( ){
 
 ////////////////////
 
+static unsigned original_screen_autolock, original_screen_stayslit;
+
+void hw_init_cp_screen_settings( ){
+	unsigned autolock = conf_get_int(conf_original_screen_autolock);
+	unsigned stayslit = conf_get_int(conf_original_screen_stayslit);
+	if(autolock){ conf_set_screen_autolock_value(autolock-1); conf_set_int(conf_original_screen_autolock, 0); }
+	if(stayslit){ conf_set_screen_stayslit_value(stayslit-1); conf_set_int(conf_original_screen_stayslit, 0); }
+
+	original_screen_autolock = original_screen_stayslit = 0;
+}
+
 void hw_restore_cp_screen_settings( ){
 	if(original_screen_autolock){
 		// restored scree_autolock setting
 		conf_set_screen_autolock_value(original_screen_autolock-1);
 		original_screen_autolock = 0;
+		conf_set_int(conf_original_screen_autolock, 0);
 	}
 	if(original_screen_stayslit){
 		// restore screen_stayslit setting
 		conf_set_screen_stayslit_value(original_screen_stayslit-1);
 		original_screen_stayslit = 0;
+		conf_set_int(conf_original_screen_stayslit, 0);
 	}
 }
 
@@ -422,6 +438,7 @@ void mce_blank_screen( ){
 		// turn off autolock
 		conf_set_screen_autolock_value(0);
 		original_screen_autolock = 2; // save ON state
+		conf_set_int(conf_original_screen_autolock, original_screen_autolock);
 	}
 
 	unsigned screen_stayslit = conf_get_screen_stayslit_value();
@@ -429,6 +446,7 @@ void mce_blank_screen( ){
 		// turn off stayslit
 		conf_set_screen_stayslit_value(0);
 		original_screen_stayslit = 2; // save ON state
+		conf_set_int(conf_original_screen_stayslit, original_screen_stayslit);
 	}
 
 	// make sure screen isn't paused
@@ -449,6 +467,7 @@ void mce_lock_and_blank_screen( ){
 		// turn on autolock
 		conf_set_screen_autolock_value(1);
 		original_screen_autolock = 1; // save OFF state
+		conf_set_int(conf_original_screen_autolock, original_screen_autolock);
 	}
 
 	unsigned screen_stayslit = conf_get_screen_stayslit_value();
@@ -456,6 +475,7 @@ void mce_lock_and_blank_screen( ){
 		// turn off stayslit
 		conf_set_screen_stayslit_value(0);
 		original_screen_stayslit = 2; // save ON state
+		conf_set_int(conf_original_screen_stayslit, original_screen_stayslit);
 	}
 
 	// make sure screen isn't paused
@@ -546,14 +566,13 @@ void mce_normal_mode( ){
 
 void mce_flight_mode( ){
 	#ifdef ARCH_armel
-	hw_entering_flight_mode = hw_wifi.enabled + hw_bluetooth.enabled;
-	// disconnect wifi so ICD won't run in flight mode
-	if(hw_wifi.enabled) hw_wifi_disconnect();
-	// turn off bluetooth in case it has similar problems
-	if(hw_bluetooth.enabled) hw_set_bluetooth(0);
-
-	// enable flight mode
-	if(!hw_entering_flight_mode){
+	if(hw_wifi.enabled){
+		// disconnect wifi so ICD won't run in flight mode
+		hw_wifi_disconnect();
+		hw_entering_flight_mode = 1;
+	} else {
+		// enable flight mode
+		hw_entering_flight_mode = 0;
 		usleep(100000); // sleep 100ms to be sure services have fully disconnected
 		dbus_send_method(_mce_service_, _mce_path_, _mce_interface_, _mce_req_device_mode_change_, _STRING_, &_mce_device_FLIGHT_, _END_);
 	}
@@ -637,9 +656,12 @@ static void bme_update_drain( ){
 		if(history == hw_battery.charge_point || timestamp < current_time - 3600.0) break; // stop at the charging point or 1 hour ago
 	}
 	hw_battery.hours1 = (current_time - timestamp >= 3600.0 ? 1 : 0); // display tilde if less than 60 minutes of data
-	hw_battery.drain1 = (current_time > timestamp + 60.0 ? // wait 1 minute
-		roundf((capacity - current_capacity) * 36000.0 / (current_time - timestamp))/10.0
-		: 0.0);
+	if(current_time > timestamp + 60.0){
+		// wait 1 minute
+		hw_battery.drain1 = roundf((capacity - current_capacity) * 36000.0 / (current_time - timestamp))/10.0;
+		if(hw_battery.drain1 < 0.0) hw_battery.drain1 = 0.0;
+	} else
+		hw_battery.drain1 = 0.0;
 
 	// last 24 hours
 	if(hw_battery.charge_point){
@@ -653,6 +675,7 @@ static void bme_update_drain( ){
 		float hours = (current_time - timestamp) / 3600.0;
 		hw_battery.hours24 = roundf(hours);
 		hw_battery.drain24 = roundf(10.0 * (capacity - current_capacity) / hours)/10.0;
+		if(hw_battery.drain24 < 0.0) hw_battery.drain24 = 0.0;
 	} else {
 		hw_battery.hours24 = 2;
 		hw_battery.drain24 = 0.0;
@@ -691,7 +714,7 @@ static void bme_get_capacity_callback( DBusPendingCall *pending, void *user_data
 						hw_battery.history_head = history;
 					else {
 						hw_battery.history_tail->next = history;
-						if(hw_battery.history_tail->capacity < capacity) hw_battery.charge_point = history; // set a charging point
+						if(hw_battery.history_tail->capacity + MIN_CHARGE_RESET < capacity) hw_battery.charge_point = history; // set a charging point
 					}
 					hw_battery.history_tail = history;
 				} else
@@ -705,7 +728,7 @@ static void bme_get_capacity_callback( DBusPendingCall *pending, void *user_data
 				s_battery_history *next = history->next;
 				if(history->timestamp > base_time) break;
 				// history element is older than storable time, remove it
-				if(hw_battery.history_head == history) hw_battery.history_head = next;
+				if(history == hw_battery.history_head) hw_battery.history_head = next;
 				if(next == NULL) hw_battery.history_tail = NULL;
 				else next->prev = NULL;
 				if(history == hw_battery.charge_point) hw_battery.charge_point = NULL; // unset charging point
@@ -767,7 +790,7 @@ static void new_battcap( double timestamp, float capacity ){
 			hw_battery.history_head = history;
 		else {
 			hw_battery.history_tail->next = history;
-			if(hw_battery.history_tail->capacity < capacity) hw_battery.charge_point = history; // set a charging point
+			if(hw_battery.history_tail->capacity + MIN_CHARGE_RESET < capacity) hw_battery.charge_point = history; // set a charging point
 		}
 		hw_battery.history_tail = history;
 	}
@@ -1622,6 +1645,8 @@ void hw_refresh( ){
 			unsigned screen_autolock = conf_get_screen_autolock_value();
 			if(hw_screen_autolock != screen_autolock){ hw_screen_autolock = screen_autolock; hw_changes |= HW_SCREEN_AUTOLOCK; }
 		}
+
+		// TODO: query sound volumes
 	}
 
 	#ifdef ARCH_armel
