@@ -53,6 +53,7 @@
 #include "hardware.h"
 #include "dialog.h"
 #include "dbus.h"
+#include "powerbutton.h"
 #include "dsme.h"
 #include "secure.h"
 #include "alarm.h"
@@ -72,6 +73,9 @@
 // button editor needs to keep rotation buttons on primary page
 #include "button_rotate.h"
 
+// shutdown dialog
+#include "button_reboot_shutdown.h"
+
 ////////////////////////////////////////////////////////////////////////// GLOBALS
 
 // device model
@@ -115,6 +119,10 @@ char *power_unlock_messages[] = {"",
 
 char *charging_boot_message = "press and hold power button to startup";
 
+#ifdef DEBUG
+static const char *click_type_names[] = {"down", "SHORT", "hold", "LONG", "motion", "drag"};
+#endif
+
 ////////////////////////////////////////////////////////////////////////// GET MICRO TIME
 
 double get_utime( ){
@@ -238,7 +246,9 @@ static void _move_button( s_button *button, unsigned cell ){
 }
 
 static void _click_button( s_button *button, unsigned cell ){
-	if(button_edit_mode && selected_cell.button && click.type == CLICK_SHORT){
+	if(!button_edit_mode) return;
+
+	if(selected_cell.button && click.type == CLICK_SHORT){
 
 		// clear selection or move selected button
 		if(button == selected_cell.button){
@@ -249,7 +259,7 @@ static void _click_button( s_button *button, unsigned cell ){
 		} else
 			_move_button(button, cell);
 
-	} else if(button_edit_mode && button){
+	} else if(button){
 
 		if(click.type == CLICK_SHORT){
 			// select button
@@ -258,8 +268,7 @@ static void _click_button( s_button *button, unsigned cell ){
 			_draw_button(1, widget_x, widget_y, button);
 		}
 
-	} else if(button)
-		button->click();
+	}
 }
 
 ////////////////////////////////////////////////////////////////////////// WIDGET CELLS
@@ -410,8 +419,10 @@ static void _click_widget( s_widget_cell *widget_cell, unsigned cell ){
 				selected_cell.subcell = 0;
 				_draw_widget(1, widget_x, widget_y, widget_cell);
 			}
-		} else
+		} else {
+			debug_write("click widget: %s [%s]", widget_cell->left->name, click_type_names[click.type]);
 			widget_cell->left->click();
+		}
 
 	} else if(widget_cell->size == HALF_WIDGET){
 
@@ -426,6 +437,7 @@ static void _click_widget( s_widget_cell *widget_cell, unsigned cell ){
 						_draw_widget(1, widget_x, widget_y, widget_cell);
 					}
 				} else {
+					debug_write("click widget: %s [%s]", widget_cell->right->name, click_type_names[click.type]);
 					widget_x += 200;
 					click.x -= 200;
 					widget_cell->right->click();
@@ -440,8 +452,10 @@ static void _click_widget( s_widget_cell *widget_cell, unsigned cell ){
 					selected_cell.subcell = 0;
 					_draw_widget(1, widget_x, widget_y, widget_cell);
 				}
-			} else
+			} else {
+				debug_write("click widget: %s [%s]", widget_cell->left->name, click_type_names[click.type]);
 				widget_cell->left->click();
+			}
 		}
 
 	}
@@ -872,7 +886,10 @@ static void click_button( unsigned button ){
 		}
 	} else {
 		button += (primary_widgets ? 0 : 10);
-		if(button_cells[button]) button_cells[button]->click(); // LANDSCAPE or PORTRAIT
+		if(button_cells[button]){
+			debug_write("click button: %s [%s]", button_cells[button]->name, click_type_names[click.type]);
+			button_cells[button]->click(); // LANDSCAPE or PORTRAIT
+		}
 	}
 }
 
@@ -908,13 +925,21 @@ int throttle_taps( s_tap_throttler *zone ){
 		int difference = zone->timestamp - click.timestamp;
 		if(difference < 0) difference = 0;
 		if(difference > 0 && difference < 60000) return 1; // ignore tap throttling if greater than 60 seconds
-		//if(click.timestamp < zone->timestamp) return 1;
 	}
 	zone->utime = current_time;
 	zone->timestamp = click.timestamp;
 	return 0;
 }
 
+static int test_tap_throttling( s_tap_throttler *zone ){
+	if(zone->timestamp){
+		int difference = zone->timestamp - click.timestamp;
+		if(difference < 0) difference = 0;
+		if(difference > 0 && difference < 60000) return 0; // ignore tap throttling if greater than 60 seconds
+	}
+	return 1;
+}
+
 static void highlight_button_bar( ){
 	x_set_color(selection_color);
 	if(window.width > window.height)
@@ -929,10 +954,10 @@ static void highlight_button_bar( ){
 static void screen_event( ){
 	if(current_dialog_draw){
 
-		if(current_dialog_click && click.timestamp > dialog_throttle.timestamp + DIALOG_THROTTLE_DURATION) current_dialog_click();
-		// dialog_throttle shoudln't be updated, this only throttles clicks while opening the dialog
+		if(current_dialog_click && test_tap_throttling(&dialog_throttle)) current_dialog_click();
+		// dialog_throttle shouldn't be updated, this only throttles clicks while opening the dialog
 
-	} else if(click.timestamp > ui_throttle.timestamp){ // throttle clicks for entire UI
+	} else if(test_tap_throttling(&ui_throttle)){ // throttle clicks for entire UI
 
 		if(window.width > window.height){
 			// LANDSCAPE
@@ -1125,19 +1150,23 @@ void press_lock_button( unsigned action ){
 	case 0: // not bound
 		break;
 	case 1: // lock
+		debug_write("    lock button action: lock");
 		if(cfg_lock_and_close && !hw_device_locked) window_unmap();
 		mce_lock_screen(1);
 		break;
 	case 2: // lock&blank
+		debug_write("    lock button action: lock&blank");
 		if(cfg_lock_and_close && !hw_device_locked) window_unmap();
 		mce_lock_and_blank_screen();
 		break;
 	case 3: // blank
+		debug_write("    lock button action: blank");
 		if(cfg_lock_and_close && !hw_device_locked) window_unmap();
 		mce_blank_screen();
 		break;
 	case 4: // secure
 		if(cfg_secure_button){
+			debug_write("    lock button action: secure");
 			press_lock_button(cfg_secure_action);
 			mce_lock_device();
 		}
@@ -1266,11 +1295,14 @@ static void clean_up( ){
 	if(clean_up_stage > 0){
 		dsme_disconnect();
 		if(clean_up_stage > 1){
-			dbus_disconnect();
-			close(dbus_fd);
+			powerbutton_disconnect();
 			if(clean_up_stage > 2){
-				window_close_blank(); // close blank window, if open
-				window_close(1); // free fonts and close display
+				dbus_disconnect();
+				close(dbus_fd);
+				if(clean_up_stage > 3){
+					window_close_blank(); // close blank window, if open
+					window_close(1); // free fonts and close display
+				}
 			}
 		}
 	}
@@ -1424,6 +1456,7 @@ if(runlevel == 2){
 
 	// initialize gconf settings
 	config_init();
+	hw_init_cp_screen_settings();
 
 	// use minimal UI in runlevel 5
 	if(runlevel == 5){
@@ -1447,6 +1480,18 @@ if(runlevel == 2){
 	dsme_fd = 0;
 	#endif
 
+	// initialize power button socket
+	int powerbutton_fd;
+	#ifdef ARCH_armel
+	if(!(powerbutton_fd = powerbutton_init())){
+		clean_up();
+		return EXIT_FAILURE;
+	}
+	clean_up_stage++;
+	#else
+	powerbutton_fd = 0;
+	#endif
+
 	// initialize alarms
 	alarm_init();
 
@@ -1500,12 +1545,13 @@ if(runlevel == 2){
 	for(;;){
 		unsigned runaway_event_counter;
 		struct timeval timeout;
-		int highest_fd = (x_fd > dbus_fd ? (x_fd > dsme_fd ? x_fd : dsme_fd) : (dbus_fd > dsme_fd ? dbus_fd : dsme_fd));
+		int highest_fd = (x_fd > dbus_fd ? x_fd : dbus_fd);
 		fd_set set;
 
 		FD_ZERO(&set);
 		#ifdef ARCH_armel
-		FD_SET(dsme_fd, &set);
+		FD_SET(dsme_fd, &set);			highest_fd = (dsme_fd        > highest_fd ? dsme_fd        : highest_fd);
+		FD_SET(powerbutton_fd, &set);	highest_fd = (powerbutton_fd > highest_fd ? powerbutton_fd : highest_fd);
 		#endif
 		FD_SET(dbus_fd, &set);
 		FD_SET(x_fd, &set);
@@ -1872,6 +1918,9 @@ if(runlevel == 2){
 					// shutdown signal received
 					debug_write("    message SHUTDOWN");
 
+					// open shutdown dialog
+					open_shutdown_dialog(0);
+
 					// detect runlevel transition (2 -> 5)
 					FILE *in = popen("runlevel", "r");
 					if(in){
@@ -1912,6 +1961,15 @@ if(runlevel == 2){
 
 		////////////////////
 
+		// power button
+		#ifdef ARCH_armel
+		debug_write("any power button events?");
+		while(ready_to_read(powerbutton_fd))
+			powerbutton_read();
+		#endif
+
+		////////////////////
+
 		// read messages from dsme socket
 		#ifdef ARCH_armel
 		debug_write("any dsme messages?");
@@ -2127,6 +2185,17 @@ if(runlevel == 2){
 			}
 		}
 
+		#ifdef ARCH_armel
+		if(powerbutton_waiting_double){
+			double powerbutton_remaining = powerbutton_check_double_tap();
+			if(powerbutton_remaining > 0.0){
+				if(next_timer_duration <= 0.0 || powerbutton_remaining < next_timer_duration)
+					next_timer_duration = powerbutton_remaining;
+				infinite_timeout = 0;
+			}
+		}
+		#endif
+
 		// refresh on dbus signals and method returns
 			// all dialogs should change on HW_THEME
 			// cpu policy dialog needs HW_CPU
