@@ -169,7 +169,7 @@ static void draw_brightness_toggle( unsigned force ){
 	}
 
 	x_set_color(red_status_color);
-	unsigned size = (unsigned)round(21.0 + (30.0 * (float)hw_screen.brightness_level / (float)hw_screen.brightness_max));
+	unsigned size = (unsigned)roundf(21.0 + (30.0 * (float)hw_screen.brightness_level / (float)hw_screen.brightness_max));
 	if((size & 1) == 0) size++; // size is always odd
 	unsigned x = 238 - (size>>1);
 	unsigned y = 50 - (size>>1);
