@@ -22,9 +22,12 @@
 #include "brightness.h"
 #include "rbv_keys.h"
 #include "button_modes.h"
+#include "power_button.h"
+#include "device_lock.h"
 #include "ui.h"
 #include "alarm.h"
 #include "services.h"
+#include "mce.h"
 
 //////////////////////////////////////////////////////////////////////////
 
@@ -81,17 +84,25 @@ const char *conf_buttons_volume_step = "/apps/asui/buttons_volume_step";
 const char *conf_double_tap = "/apps/asui/double_tap";
 const char *conf_lock_and_close = "/apps/asui/lock_and_close";
 const char *conf_rotate_and_close = "/apps/asui/rotate_and_close";
+const char *conf_split_lock_buttons = "/apps/asui/split_lock_buttons";
 const char *conf_buttons_dpad_short = "/apps/asui/buttons_dpad_short";
 const char *conf_buttons_dpad_long = "/apps/asui/buttons_dpad_long";
 const char *conf_buttons_lock1_short = "/apps/asui/buttons_lock1_short";
 const char *conf_buttons_lock1_long = "/apps/asui/buttons_lock1_long";
 const char *conf_buttons_lock2_short = "/apps/asui/buttons_lock2_short";
 const char *conf_buttons_lock2_long = "/apps/asui/buttons_lock2_long";
-const char *conf_secure_action = "/apps/asui/secure_action";
-const char *conf_secure_power_action = "/apps/asui/secure_power_action";
-const char *conf_secure_button = "/apps/asui/secure_button";
-const char *conf_power_action = "/apps/asui/power_action";
+// power button
+const char *conf_power_enable_double = "/apps/asui/power_enable_double";
+const char *conf_power_action_single = "/apps/asui/power_action_single";
+const char *conf_power_action_double = "/apps/asui/power_action_double";
+const char *conf_power_longpress_shutdown = "/apps/asui/power_longpress_shutdown";
+const char *conf_power_blanks_when_locked = "/apps/asui/power_blanks_when_locked";
 const char *conf_power_unlock_key = "/apps/asui/power_unlock_key";
+// device lock
+const char *conf_secure_button = "/apps/asui/secure_button";
+const char *conf_secure_action = "/apps/asui/secure_action";
+const char *conf_secure_power_action_single = "/apps/asui/secure_power_action_single";
+const char *conf_secure_power_action_double = "/apps/asui/secure_power_action_double";
 // user interface
 const char *conf_tkactive_notifications = "/apps/asui/tkactive_notifications";
 const char *conf_service_size_unit = "/apps/asui/service_size_unit";
@@ -325,8 +336,15 @@ static gint on_key_press_event ( GtkWidget *widget, GdkEventKey *keyevent, gpoin
 	return FALSE;
 }
 
-static void new_main_label( char *name ){
+void new_main_separator( ){
+	GtkWidget *line = gtk_hseparator_new();
+	gtk_box_pack_start(GTK_BOX(main_content_box), line, FALSE, FALSE, 10);
+	gtk_widget_show(line);
+}
+
+static void new_main_label( unsigned wrap, char *name ){
 	GtkWidget *label = gtk_label_new(name);
+	if(wrap) gtk_label_set_line_wrap(GTK_LABEL(label), TRUE);
 	gtk_box_pack_start(GTK_BOX(main_content_box), label, FALSE, FALSE, 10);
 	gtk_widget_show(label);
 }
@@ -414,20 +432,21 @@ int main( int argc, char *argv[] ){
 	gtk_widget_show(window_vbox);
 
 	new_scrolling_vbox(window_vbox, &main_box, &main_content_box);
-	new_main_label("Widgets");
-	new_main_button(main_content_box, "Battery", battery_click_callback);
-	new_main_button(main_content_box, "Clock", clock_click_callback);
-	new_main_button(main_content_box, "Brightness", brightness_click_callback);
-	new_main_label("Other");
-	new_main_button(main_content_box, "RBV Keys", rbv_keys_click_callback);
-	new_main_button(main_content_box, "Button Modes", button_modes_click_callback);
-	new_main_button(main_content_box, "User Interface", ui_click_callback);
-	new_main_button(main_content_box, "Alarm", alarm_click_callback);
-	new_main_button(main_content_box, "Services", services_click_callback);
-	// footer
-	GtkWidget *line = gtk_hseparator_new(); gtk_box_pack_start(GTK_BOX(main_content_box), line, FALSE, FALSE, 10); gtk_widget_show(line);
-	GtkWidget *label = gtk_label_new("all settings in this app instantly reload ASUI when changed");
-	gtk_label_set_line_wrap(GTK_LABEL(label), TRUE); gtk_box_pack_start(GTK_BOX(main_content_box), label, FALSE, FALSE, 10); gtk_widget_show(label);
+		new_main_button(main_content_box, "Battery", battery_click_callback);
+		new_main_button(main_content_box, "Clock", clock_click_callback);
+		new_main_button(main_content_box, "Brightness", brightness_click_callback);
+	new_main_separator();
+		new_main_button(main_content_box, "RBV Keys", rbv_keys_click_callback);
+		new_main_button(main_content_box, "Button Modes", button_modes_click_callback);
+		new_main_button(main_content_box, "Power Button", power_button_click_callback);
+		new_main_button(main_content_box, "Device Lock", device_lock_click_callback);
+		new_main_button(main_content_box, "User Interface", ui_click_callback);
+		new_main_button(main_content_box, "Alarm", alarm_click_callback);
+	new_main_separator();
+		new_main_button(main_content_box, "Services", services_click_callback);
+		new_main_button(main_content_box, "MCE", mce_click_callback);
+	new_main_separator();
+		new_main_label(0, "changes to settings instantly reload ASUI");
 
 	// gtk main loop
 	gtk_main();
