@@ -51,17 +51,25 @@ extern const char *conf_buttons_volume_step;
 extern const char *conf_double_tap;
 extern const char *conf_lock_and_close;
 extern const char *conf_rotate_and_close;
+extern const char *conf_split_lock_buttons;
 extern const char *conf_buttons_dpad_short;
 extern const char *conf_buttons_dpad_long;
 extern const char *conf_buttons_lock1_short;
 extern const char *conf_buttons_lock1_long;
 extern const char *conf_buttons_lock2_short;
 extern const char *conf_buttons_lock2_long;
-extern const char *conf_secure_action;
-extern const char *conf_secure_power_action;
-extern const char *conf_secure_button;
-extern const char *conf_power_action;
+// power button
+extern const char *conf_power_enable_double;
+extern const char *conf_power_action_single;
+extern const char *conf_power_action_double;
+extern const char *conf_power_longpress_shutdown;
+extern const char *conf_power_blanks_when_locked;
 extern const char *conf_power_unlock_key;
+// device lock
+extern const char *conf_secure_button;
+extern const char *conf_secure_action;
+extern const char *conf_secure_power_action_single;
+extern const char *conf_secure_power_action_double;
 // user interface
 extern const char *conf_tkactive_notifications;
 extern const char *conf_service_size_unit;
