@@ -1,7 +1,7 @@
 //	Advanced System UI
 //	Copyright (c) 2011 Brand Huntsman <brand.huntsman@gmail.com>
 
-#define ASUI_VERSION "0.5.7"
+#define ASUI_VERSION "0.5.8"
 
 /*
 /etc/init.d/hildon-desktop stop
@@ -26,10 +26,18 @@ su - user -c "maemo-summoner /usr/bin/hildon-desktop.launch"
 
 #include <gconf/gconf-client.h>
 #define conf_get_bool(key) gconf_client_get_bool(p->gconf_client, key, (GError **)NULL)
+#define conf_get_int(key) gconf_client_get_int(p->gconf_client, key, (GError **)NULL)
 #define KEYNAME_PATH "/apps/asui"
 #define USE_BATTERY_KEYNAME "/enable_battery_applet"
 static const char *conf_enable_battery_applet = KEYNAME_PATH USE_BATTERY_KEYNAME;
 
+#define _STRING_ DBUS_TYPE_STRING
+#define _BOOL_ DBUS_TYPE_BOOLEAN
+#define _UINT32_ DBUS_TYPE_UINT32
+#define _INT32_ DBUS_TYPE_INT32
+#define _DOUBLE_ DBUS_TYPE_DOUBLE
+#define _END_ DBUS_TYPE_INVALID
+
 //////////////////////////////////////////////////////////////////////////
 
 G_BEGIN_DECLS
@@ -83,8 +91,25 @@ static const char *charging_notification = "Charging...";
 static const char *battery_full_notification = "Battery Full";
 static const char *battery_low_notification = "Low Battery";
 
-static void display_notification( AsuiBatteryPluginPrivate *p, const char *msg ){
-	// initialize dbus
+static const char *charging_sound = "/usr/share/sounds/ui-charging_started.wav";
+static const char *battery_low_sound = "/usr/share/sounds/ui-battery_low.wav";
+
+static void asui_battery_dbus_send_session_method( DBusConnection *bus, const char *destination, const char *path, const char *interface, const char *method, int first_arg_type, ... ){
+	DBusMessage *message = dbus_message_new_method_call(destination, path, interface, method);
+	dbus_message_set_no_reply(message, TRUE);
+	va_list ap;
+	if(first_arg_type != _END_){
+		va_start(ap, first_arg_type);
+		dbus_message_append_args_valist(message, first_arg_type, ap);
+		va_end(ap);
+	}
+	if(dbus_connection_send(bus, message, NULL) != FALSE)
+		dbus_connection_flush(bus);
+	dbus_message_unref(message);
+}
+
+static void asui_battery_display_notification( AsuiBatteryPluginPrivate *p, const char *msg, const char *sound ){
+	// initialize dbus connection
 	DBusGConnection *connection;
 	GError *error = NULL;
 	if((connection = dbus_g_bus_get(DBUS_BUS_SESSION, &error)) == NULL){
@@ -94,13 +119,28 @@ static void display_notification( AsuiBatteryPluginPrivate *p, const char *msg )
 	}
 	DBusConnection *session_bus = dbus_g_connection_get_connection(connection);
 
-	DBusMessage *message = dbus_message_new_method_call(
-		"org.freedesktop.Notifications", "/org/freedesktop/Notifications", "org.freedesktop.Notifications", "SystemNoteInfoprint");
-	dbus_message_set_no_reply(message, TRUE);
-	dbus_message_append_args(message, DBUS_TYPE_STRING, &msg, DBUS_TYPE_INVALID);
-	if(dbus_connection_send(session_bus, message, NULL) != FALSE)
-		dbus_connection_flush(session_bus);
-	dbus_message_unref(message);
+	// play sound
+	if(sound){
+		unsigned system_alert_volume = conf_get_int("/apps/osso/sound/system_alert_volume");
+		if(system_alert_volume){
+			const char *mm_service = "com.nokia.osso_media_server";
+			const char *mm_path = "/com/nokia/osso_media_server";
+			const char *mm_interface = "com.nokia.osso_media_server.sound";
+			double volume = 0.5 * system_alert_volume;
+			unsigned loop = 0;
+			int priority = 1;
+
+			asui_battery_dbus_send_session_method(session_bus, mm_service, mm_path, mm_interface, "set_volume", _DOUBLE_, &volume, _END_);
+			asui_battery_dbus_send_session_method(session_bus, mm_service, mm_path, mm_interface, "set_loop", _BOOL_, &loop, _END_);
+			asui_battery_dbus_send_session_method(session_bus, mm_service, mm_path, mm_interface, "play_sound", _STRING_, &sound, _INT32_, &priority, _END_);
+		}
+	}
+
+	// display notification
+	asui_battery_dbus_send_session_method(session_bus, "org.freedesktop.Notifications", "/org/freedesktop/Notifications", "org.freedesktop.Notifications",
+											"SystemNoteInfoprint", _STRING_, &msg, _END_);
+
+	// close dbus connection
 	dbus_g_connection_unref(connection);
 }
 
@@ -148,7 +188,7 @@ static void asui_battery_dbus_send_method( AsuiBatteryPluginPrivate *p, const ch
 	dbus_message_unref(message);
 }
 
-static void asui_battery_update_icon( AsuiBatteryPluginPrivate *p );
+static void asui_battery_update_icon( AsuiBatteryPluginPrivate *p ); // prototype
 
 static gboolean asui_battery_reset_press( gpointer data ){
 	asui_battery_update_icon((AsuiBatteryPluginPrivate *)data);
@@ -222,7 +262,7 @@ static DBusHandlerResult asui_battery_signal_filter( DBusConnection *connection,
 	if(dbus_message_is_signal(message, "com.qzx.asui", "charging_status")){
 		unsigned status;
 		dbus_error_init(&dbus_error);
-		if(dbus_message_get_args(message, &dbus_error, DBUS_TYPE_UINT32, &status, DBUS_TYPE_INVALID)){
+		if(dbus_message_get_args(message, &dbus_error, _UINT32_, &status, _END_)){
 			asui_battery_initializing &= 1;
 			if(asui_battery_status != status){
 				asui_battery_status = status;
@@ -233,7 +273,7 @@ static DBusHandlerResult asui_battery_signal_filter( DBusConnection *connection,
 	} else if(dbus_message_is_signal(message, "com.qzx.asui", "battery_capacity")){
 		unsigned capacity;
 		dbus_error_init(&dbus_error);
-		if(dbus_message_get_args(message, &dbus_error, DBUS_TYPE_UINT32, &capacity, DBUS_TYPE_INVALID)){
+		if(dbus_message_get_args(message, &dbus_error, _UINT32_, &capacity, _END_)){
 			asui_battery_initializing &= 2;
 			if(asui_battery_capacity != capacity){
 				asui_battery_capacity = capacity;
@@ -242,13 +282,13 @@ static DBusHandlerResult asui_battery_signal_filter( DBusConnection *connection,
 		}
 		return DBUS_HANDLER_RESULT_HANDLED;
 	} else if(dbus_message_is_signal(message, "com.nokia.bme.signal", "battery_low")){
-		display_notification((AsuiBatteryPluginPrivate *)user_data, battery_low_notification);
+		asui_battery_display_notification((AsuiBatteryPluginPrivate *)user_data, battery_low_notification, battery_low_sound);
 		return DBUS_HANDLER_RESULT_HANDLED;
 	} else if(dbus_message_is_signal(message, "com.nokia.bme.signal", "battery_full")){
-		display_notification((AsuiBatteryPluginPrivate *)user_data, battery_full_notification);
+		asui_battery_display_notification((AsuiBatteryPluginPrivate *)user_data, battery_full_notification, NULL);
 		return DBUS_HANDLER_RESULT_HANDLED;
 	} else if(dbus_message_is_signal(message, "com.nokia.bme.signal", "charger_connected")){
-		display_notification((AsuiBatteryPluginPrivate *)user_data, charging_notification);
+		asui_battery_display_notification((AsuiBatteryPluginPrivate *)user_data, charging_notification, charging_sound);
 		return DBUS_HANDLER_RESULT_HANDLED;
 	}
 	return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
