@@ -27,7 +27,7 @@
  #include "widget_battery.h"
 
 #include "battery_graph.h"
-#include "procviewer.h"
+#include "process_viewer.h"
 #include "governor_dsp.h"
 
 //////////////////////////////////////////////////////////////////////////
@@ -152,7 +152,7 @@ void draw_battery_widget( unsigned force, int x, int y ){
 		}
 	}
 	if(!hw_device_locked){
-		if(cfg_battery_usage){
+		if(cfg_battery_usage && !use_minimal_ui){
 			int w;
 
 			#define OFFSET_LABEL 85
@@ -213,7 +213,7 @@ void draw_battery_widget( unsigned force, int x, int y ){
 			}
 		}
 
-		draw_tap_markers(x, y, 99, 1, cfg_history_days); // short and long tap
+		if(!use_minimal_ui) draw_tap_markers(x, y, 99, 1, cfg_history_days); // short and long tap
 	}
 
 	////////////////////
@@ -236,7 +236,7 @@ void draw_battery_widget( unsigned force, int x, int y ){
 				x+246, y+92, ALIGN_CENTER, ALIGN_BOTTOM, 0);
 		}
 
-		if(!drawing_popup_window) draw_tap_markers(x+201, y, 99, 1, hw_swap.total); // short tap only (long tap if swap is enabled)
+		if(!drawing_popup_window) draw_tap_markers(x+200, y, 99, 1, hw_swap.total); // short tap only (long tap if swap is enabled)
 
 		x_set_color(line_color);
 		x_draw_line(x+292, y, x+292, y+99);
@@ -282,7 +282,7 @@ void click_battery_widget( ){
 			if(throttle_taps(&dialog_throttle)) return;
 
 			highlight_selected_area(widget_x+293, widget_y, 106, 99);
-			governor_open_dialog();
+			governor_dsp_open_dialog();
 
 			finalize_tap(dialog_throttle);
 
@@ -315,7 +315,7 @@ void click_battery_widget( ){
 			if(throttle_taps(&dialog_throttle)) return;
 
 			highlight_selected_area(widget_x+200, widget_y, 92, 99);
-			procviewer_open_dialog();
+			process_viewer_open_dialog();
 
 			finalize_tap(dialog_throttle);
 		}
