@@ -314,7 +314,7 @@ static int window_create( unsigned first_time ){
 		int i = 0;
 		x_get_color("#000000", "#ffffff"); // bg_color
 		x_get_color("#444444", "#bbbbbb"); // line_color
-		x_get_color("#333333", "#cccccc"); // innerline_color
+		x_get_color("#333333", "#e3e3e3"); // innerline_color
 		x_get_color("#dddddd", "#222222"); // fg1_color
 		x_get_color("#aaaaaa", "#555555"); // fg2_color
 		x_get_color("#ffffff", "#000000"); // white_color
@@ -326,7 +326,7 @@ static int window_create( unsigned first_time ){
 		x_get_color("#aaaaff", "#6666dd"); // scrollbar_color
 		x_get_color("#555555", "#aaaaaa"); // scroller_color
 		x_get_color("#7777ff", "#0000dd"); // selection_color
-		x_get_color("#fb9200", "#ee6100"); // secondary_selection_color
+		x_get_color("#fb9200", "#ee8a00"); // secondary_selection_color
 
 		// load images
 		load_xpm(button_toflightmode_icon, &im_toflight);
